@@ -16,10 +16,10 @@ class UsersService(CommonMixin, NameMixin, PrintMixin):
         add user to group
         """
 
-        self.__base.post(f"api/groups/{group_id}/members", {"user_id": user_id})
+        self.__base.post(f"/api/groups/{group_id}/members", {"user_id": user_id})
 
     def remove_group(self, user_id: int, group_id: int) -> None:
         """
         remove user from group
         """
-        self.__base.delete(f"api/groups/{group_id}/members/{user_id}")
+        self.__base.delete(f"/api/groups/{group_id}/members/{user_id}")
